# 					-*- mode: python; coding: utf-8 -*-
#
#  Quelques outils pour la manipulation d'images en CiP
#
#           Author: Erick Gallesio [eg@unice.fr]
#    Creation date:  8-Nov-2009 11:08 (eg)
# Last file update:  9-Oct-2011 15:35 (eg)

from cip import *
from math import *

#
# Une classe pour représenter des pixels
#
class Pixel:
    "Un pixel RVB."
    def __init__(self, R =0, G =0, B =0):
        self.R = R
        self.G = G
        self.B = B

    def __eq__(self, x):
        return (self.R == x.R) and (self.G == x.G) and (self.B == x.B) 

    def __repr__(self):
        return "{Pix %d,%d,%d}" % (self.R, self.G, self.B)

#
# Une classe pour représenter des images
#
class Image:
    "Une image."
    def __init__(self, width, height, depth, pixels):
        self.width  = width
        self.height = height
        self.depth  = depth
        self.pixels = pixels

    def __repr__(self):
        return "{Img %dx%d (%d) => %s}" % (self.width, self.height, self.depth,
                                           self.pixels)

# Le lecteur d'image PPM. Il renvoit 4 valeurs: largeur, hauteur, prof., pixels
# où pixel est un tableau de largeur x hauteur entiers compris entre 0 et 255
def readPPM(filename):
    if (filename):
        f = open(filename, "r")
    else:
        f = stdin

    res = []
    for line in f:
        if (line[0] != "#"):
            if line.strip() == "P3" :
                res.append("P3")
            else:
                # Ajouter tous les items de la ligne après conversion en int
                for i in line.split():
                    res.append(int(i))
    if (filename):
        f.close()
    return res[1],res[2],res[3], res[4:]

#
# Read_image: 
#
def read_image(filename = False):
    """Renvoie l'image correspondant au fichier passé en paramètre.
       Si filename = False, la lecture se fait sur le fichier standard d'entrée"""

    width, height, depth, data=readPPM(filename)
    # Convertir data en un tableau de pixels
    pix = []
    for i in range(0, len(data), 3):
        pix.append(Pixel(data[i], data[i+1], data[i+2]))
    return Image(width, height, depth, pix)
